@@ -72,6 +72,8 @@ class OntoGraf:
         self.shacl_color = "darkgreen"
         self.arrowhead = "vee"
 
+        self.label_lang = kwargs.get('label_language', 'en')
+
         self.include = kwargs.get('include')
         self.exclude = kwargs.get('exclude')
         self.include_pattern = kwargs.get('include_pattern')
@@ -330,7 +332,7 @@ class OntoGraf:
         return deepest
 
     def gather_instance_info(self):
-        predicate_query = """
+        predicate_query = Template("""
         prefix owl: <http://www.w3.org/2002/07/owl#>
         prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
         prefix xsd: <http://www.w3.org/2001/XMLSchema#>
@@ -339,20 +341,25 @@ class OntoGraf:
         prefix skos: <http://www.w3.org/2004/02/skos/core#>
 
         select distinct ?predicate ?label ?type where {
-          ?s ?predicate ?o
-          FILTER(?predicate NOT IN (rdf:type, skos:prefLabel, skos:definition))
+          {
+            select distinct ?predicate where {
+              ?s ?predicate ?o
+              FILTER(?predicate NOT IN (rdf:type, rdfs:label, skos:prefLabel, skos:altLabel, skos:definition))
+            }
+          }
           FILTER (!STRSTARTS(STR(?predicate), 'http://www.w3.org/2002/07/owl#'))
           FILTER (!STRSTARTS(STR(?predicate), 'http://www.w3.org/1999/02/22-rdf-syntax-ns#'))
           FILTER (!STRSTARTS(STR(?predicate), 'http://www.w3.org/2000/01/rdf-schema#'))
           OPTIONAL {
             ?predicate skos:prefLabel|rdfs:label ?label
+            FILTER(lang(?label) = '$language' || lang(?label) = '')
           }
           OPTIONAL {
             values ?type { owl:DatatypeProperty owl:ObjectProperty }
             ?predicate a ?type
           }
         }
-        """
+        """).substitute(language=self.label_lang)
         self.node_data = {}
         if self.repo:
             all_predicates = list(self.select_query(predicate_query))
@@ -408,7 +415,7 @@ class OntoGraf:
             self.add_shacl_coloring()
 
     def build_class_hierarchy(self):
-        inheritance_query = """
+        inheritance_query = Template("""
         prefix owl: <http://www.w3.org/2002/07/owl#>
         prefix rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>
         prefix rdfs: <http://www.w3.org/2000/01/rdf-schema#>
@@ -416,7 +423,7 @@ class OntoGraf:
 
         select distinct ?class ?c_label ?parent ?p_label where {
           {
-              ?class rdfs:subClassOf+ ?parent .
+              ?class rdfs:subClassOf ?parent .
           }
           UNION
           {
@@ -424,10 +431,16 @@ class OntoGraf:
             ?parent a owl:Class
           }
           filter (!isblank(?class) && !isblank(?parent))
-          OPTIONAL { ?class rdfs:label|skos:prefLabel ?c_label }
-          OPTIONAL { ?parent rdfs:label|skos:prefLabel ?p_label }
+          OPTIONAL {
+              ?class rdfs:label|skos:prefLabel ?c_label
+              FILTER(lang(?c_label) = '$language' || lang(?c_label) = '')
+          }
+          OPTIONAL {
+              ?parent rdfs:label|skos:prefLabel ?p_label
+              FILTER(lang(?p_label) = '$language' || lang(?p_label) = '')
+          }
         }
-        """
+        """).substitute(language=self.label_lang)
         if self.repo:
             parents = list(self.select_query(inheritance_query))
         else:
@@ -505,7 +518,7 @@ class OntoGraf:
             return
         if src_uri not in self.node_data:
             if src_uri is None:
-                raise "None src_uri in " + str(usage)
+                raise Exception("None src_uri in " + str(usage))
             src = {
                 'label': self.class_names.get(src_uri, self.strip_uri(src_uri)),
                 'links': defaultdict(int),
@@ -522,7 +535,7 @@ class OntoGraf:
         else:
             if tgt_uri not in self.node_data:
                 if tgt_uri is None:
-                    raise "None src_uri in " + str(usage)
+                    raise Exception("None tgt_uri in " + str(usage))
                 self.node_data[tgt_uri] = {
                     'label': self.class_names.get(tgt_uri, self.strip_uri(tgt_uri)),
                     'links': defaultdict(int),
@@ -557,7 +570,7 @@ class OntoGraf:
 
             select ?src (COUNT(?src) as ?num) where {
               {
-                select (group_concat(?o) as ?src) where {
+                select (group_concat(?o;separator=' ') as ?src) where {
                   $pattern
                   FILTER(!ISBLANK(?s))
                   FILTER (!STRSTARTS(STR(?o), 'http://www.w3.org/2002/07/owl#'))
@@ -582,7 +595,7 @@ class OntoGraf:
 
                 select ?src ?tgt (COUNT(?src) as ?num) where {
                   {
-                    select (group_concat(?src_c) as ?src) (group_concat(?tgt_c) as ?tgt) where {
+                    select (group_concat(?src_c;separator=' ') as ?src) (group_concat(?tgt_c;separator=' ') as ?tgt) where {
                       $pattern
                       FILTER(!ISBLANK(?s))
                       ?s a ?src_c .
@@ -603,7 +616,7 @@ class OntoGraf:
 
                 select ?src ?dt (COUNT(?src) as ?num) where {
                   {
-                    select (group_concat(?src_c) as ?src) (SAMPLE(?dtype) as ?dt) where {
+                    select (group_concat(?src_c;separator=' ') as ?src) (SAMPLE(COALESCE(?dtype, xsd:string)) as ?dt) where {
                       $pattern
                       FILTER(!ISBLANK(?s) && ISLITERAL(?o))
                       ?s a ?src_c .
@@ -631,7 +644,7 @@ class OntoGraf:
                     {
                       select ?src ?tgt (COUNT(?src) as ?num) where {
                         {
-                            select (group_concat(?src_c) as ?src) (group_concat(?tgt_c) as ?tgt) where {
+                            select (group_concat(?src_c;separator=' ') as ?src) (group_concat(?tgt_c;separator=' ') as ?tgt) where {
                               $pattern
                               FILTER(!ISBLANK(?s))
                               ?s a ?src_c .
@@ -647,7 +660,7 @@ class OntoGraf:
                     {
                       select ?src ?dt (COUNT(?src) as ?num) where {
                         {
-                            select (group_concat(?src_c) as ?src) (SAMPLE(?dtype) as ?dt) where {
+                            select (group_concat(?src_c;separator=' ') as ?src) (SAMPLE(COALESCE(?dtype, xsd:string)) as ?dt) where {
                               $pattern
                               FILTER(!ISBLANK(?s) && ISLITERAL(?o))
                               ?s a ?src_c .
@@ -812,7 +825,7 @@ class OntoGraf:
                                   arrowhead='normal')
                 self.graf.add_edge(edge)
 
-        self.graf.write(self.outdot)
+        self.graf.write(self.outdot, encoding="utf-8")
         if not self.no_image:
             self.graf.write_png(self.outpng)
         logging.debug("Plots saved")
